@@ -68,6 +68,7 @@ sub get_spvm_core_header_file_names {
     spvm_api_runtime.h
     spvm_api_string_buffer.h
     spvm_api_type.h
+    spvm_api_internal.h
     spvm_array_field_access.h
     spvm_attribute.h
     spvm_basic_type.h
@@ -140,6 +141,7 @@ sub get_spvm_core_source_file_names {
     spvm_api_runtime.c
     spvm_api_string_buffer.c
     spvm_api_type.c
+    spvm_api_internal.c
     spvm_array_field_access.c
     spvm_attribute.c
     spvm_basic_type.c
