@@ -9,7 +9,7 @@
 #include <string.h>
 #include <stdarg.h>
 
-#define SPVM_NATIVE_VERSION_NUMBER 0.989045
+#define SPVM_NATIVE_VERSION_NUMBER 0.989046
 
 #define SPVM_NATIVE_CREATE_VERSION_STRING_STRINGIFY(x) #x
 
@@ -97,7 +97,7 @@ union spvm_value {
 
 
 struct spvm_env {
-  void* compiler;
+  void* reserved0;
   void* runtime;
   SPVM_ENV_API* api;
   SPVM_ENV* (*new_env)(void);
@@ -293,26 +293,29 @@ struct spvm_env {
   void* (*strerror_string_nolen)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t errno_value);
   const char* (*strerror)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t errno_value, int32_t length);
   const char* (*strerror_nolen)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t errno_value);
-  void* allocator;
-  void* (*new_memory_env)(SPVM_ENV* env, size_t size);
-  void (*free_memory_env)(SPVM_ENV* env, void* block);
-  int32_t (*get_memory_blocks_count_env)(SPVM_ENV* env);
+  void* reserved196;
+  void* reserved197;
+  void* reserved198;
+  void* reserved199;
   void* (*new_memory_stack)(SPVM_ENV* env, SPVM_VALUE* stack, size_t size);
   void (*free_memory_stack)(SPVM_ENV* env, SPVM_VALUE* stack, void* block);
   int32_t (*get_memory_blocks_count_stack)(SPVM_ENV* env, SPVM_VALUE* stack);
   SPVM_VALUE* (*new_stack)(SPVM_ENV* env);
   void (*free_stack)(SPVM_ENV* env, SPVM_VALUE* stack);
-  void* reserved209;
-  void* reserved208;
+  void* reserved205;
+  void* reserved206;
   void* reserved207;
   void* (*get_field_object_defined_and_has_pointer_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object, const char* field_name, int32_t* error_id, const char* func_name, const char* file_name, int32_t line);
   void** (*get_field_object_ref)(SPVM_ENV* env, SPVM_VALUE* stack, void* object, void* field);
   void** (*get_field_object_ref_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object, const char* field_name, int32_t* error_id, const char* func_name, const char* file, int32_t line);
   int32_t (*check_stack_env)(SPVM_ENV* env, SPVM_VALUE* stack);
   void* reserved212;
-  void (*leave_scope_local)(SPVM_ENV* env, SPVM_VALUE* stack, void** object_vars, int32_t* mortal_stack, int32_t* mortal_stack_top_ptr, int32_t original_mortal_stack_top);
+  void* reserved213;
   void (*assign_object)(SPVM_ENV* env, SPVM_VALUE* stack, void** dist_ref, void* object);
   void* (*new_string_array_no_mortal)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t length);
+  void* (*new_memory_block)(SPVM_ENV* env, SPVM_VALUE* stack, size_t size);
+  void (*free_memory_block)(SPVM_ENV* env, SPVM_VALUE* stack, void* block);
+  int32_t (*get_memory_blocks_count)(SPVM_ENV* env, SPVM_VALUE* stack);
 };
 
 struct spvm_env_api {
@@ -385,6 +388,8 @@ struct spvm_api_runtime {
   int32_t (*get_basic_types_length)(void* runtime);
   void (*build_precompile_module_source)(void* runtime, void* string_buffer, void* module_basic_type);
   void (*build_precompile_method_source)(void* runtime, void* string_buffer, void* method);
+  void* (*get_compiler)(void* runtime);
+  void (*set_compiler)(void* runtime, void* compiler);
 };
 
 struct spvm_api_basic_type {
