@@ -10,12 +10,6 @@ These APIs are used in L<native classes|SPVM::Document::NativeClass>.
 
 =head1 Native APIs
 
-=head2 compiler
-
-  void* compiler;
-
-The compiler object that builds the L</"runtime">.
-
 =head2 runtime
 
   void* runtime;
@@ -104,12 +98,6 @@ L<SPVM::Document::NativeAPI::Type>
 
 L<SPVM::Document::NativeAPI::Internal>
 
-=head2 allocator
-
-  void* allocator;
-
-The memory allocator for this environment.
-
 =head2 new_env
 
   SPVM_ENV* (*new_env)();
@@ -1657,35 +1645,23 @@ If the string is C<NULL>, nothing is printed.
 
   void (*free_stack)(SPVM_ENV* env, SPVM_VALUE* stack);
 
-=head2 new_memory_env
-
-  void* (*new_memory_env)(SPVM_ENV* env, size_t size);
-
-Creates a new memory block that is managed by the environment with the byte size and return the address. If it fails, return C<NULL>.
-
-The count of the memory block that is managed by the environment is incremented by 1.
-
-=head2 free_memory_env
-
-  void (*free_memory_env)(SPVM_ENV* env, void* block);
-
-Frees the memory block that is managed by the environment.
-
-The count of the memory block that is managed by the environment is decremented by 1.
-
-=head2 get_memory_blocks_count_env
-
-  int32_t (*get_memory_blocks_count_env)(SPVM_ENV* env);
-
-Returns the count of the memory blocks on the environment.
-
-This is the same as L</"get_memory_blocks_count">. This is more understandable name that memories are managed by the environment.
-
 =head2 new_memory_stack
 
+(Deprecated)
+
   void* (*new_memory_stack)(SPVM_ENV* env, SPVM_VALUE* stack, size_t size);
 
-Creates a new memory block that is managed by the stack of the environment with the byte size and return the address. If it fails, return C<NULL>.
+Creates a new memory block that is managed by the call stack with the byte size and return the address. If it fails, return C<NULL>.
+
+The count of the memory block that is managed by the stack is incremented by 1.
+
+The count of the memory block that is managed by the environment is incremented by 1.
+
+=head2 new_memory_block
+
+  void* (*new_memory_block)(SPVM_ENV* env, SPVM_VALUE* stack, size_t size);
+
+Creates a new memory block that is managed by the call stack with the byte size and return the address. If it fails, return C<NULL>.
 
 The count of the memory block that is managed by the stack is incremented by 1.
 
@@ -1693,9 +1669,21 @@ The count of the memory block that is managed by the environment is incremented
 
 =head2 free_memory_stack
 
+(Deprecated)
+
   void (*free_memory_stack)(SPVM_ENV* env, SPVM_VALUE* stack, void* block);
 
-Frees the memory block that is managed by the environment.
+Frees the memory block that is managed by the call stack.
+
+The count of the memory block that is managed by the stack is decremented by 1.
+
+The count of the memory block that is managed by the environment is decremented by 1.
+
+=head2 free_memory_block
+
+  void (*free_memory_block)(SPVM_ENV* env, SPVM_VALUE* stack, void* block);
+
+Frees the memory block that is managed by the call stack.
 
 The count of the memory block that is managed by the stack is decremented by 1.
 
@@ -1703,10 +1691,18 @@ The count of the memory block that is managed by the environment is decremented
 
 =head2 get_memory_blocks_count_stack
 
+(Deprecated)
+
   int32_t (*get_memory_blocks_count_stack)(SPVM_ENV* env, SPVM_VALUE* stack);
 
 Returns the count of the memory blocks on the stack.
 
+=head2 get_memory_blocks_count
+
+  int32_t (*get_memory_blocks_count)(SPVM_ENV* env, SPVM_VALUE* stack);
+
+Returns the count of the memory blocks on the stack.
+
 =head2 strerror
 
   const char* (*strerror)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t errno_value, int32_t length);
@@ -1955,12 +1951,6 @@ If an excetpion is thrown because the field does not exist or other errors occur
 
 If the env of the stack is equal to the env, returns 1. Otherwise returns 0.
 
-=head2 leave_scope_local
-
-C<void (*leave_scope_local)(SPVM_ENV* env, SPVM_VALUE* stack, void** object_vars, int32_t* mortal_stack, int32_t* mortal_stack_top_ptr, int32_t original_mortal_stack_top);>
-
-Leave scope using local mortal stack.
-
 =head2 assign_object
 
 C<void (*assign_object)(SPVM_ENV* env, SPVM_VALUE* stack, void** ref, void* object);>
@@ -1971,7 +1961,7 @@ Assigns an object C<object> to the place referred by the reference C<ref>.
 
 Native APIs have its IDs. These IDs are permanently same for the binary compatibility after the future release C<v1.0>.
 
-  0 compiler
+  0 reserved0
   1 runtime
   2 api
   3 new_env
@@ -2167,10 +2157,10 @@ Native APIs have its IDs. These IDs are permanently same for the binary compatib
   193 strerror_string_nolen
   194 strerror
   195 strerror_nolen
-  196 allocator
-  197 new_memory_env
-  198 free_memory_env
-  199 get_memory_blocks_count_env
+  196 reserved196
+  197 reserved197
+  198 reserved198
+  199 reserved199
   200 new_memory_stack
   201 free_memory_stack
   202 get_memory_blocks_count_stack
@@ -2184,7 +2174,7 @@ Native APIs have its IDs. These IDs are permanently same for the binary compatib
   210 get_field_object_ref_by_name
   211 check_stack_env,
   212 reserved212
-  213 leave_scope_local
+  213 reserved213
   214 assign_object
   215 new_string_array_no_mortal
   
