@@ -16,7 +16,7 @@ int32_t SPVM__TestCase__NativeAPI__check_native_api_indexes(SPVM_ENV* env, SPVM_
   
   void** env_array = (void**)env;
   
-  if ((void*)&env->compiler != &env_array[0]) { stack[0].ival = 0; return 0; }
+  if ((void*)&env->reserved0 != &env_array[0]) { stack[0].ival = 0; return 0; }
   if ((void*)&env->runtime != &env_array[1]) { stack[0].ival = 0; return 0; }
   if ((void*)&env->api != &env_array[2]) { stack[0].ival = 0; return 0; }
   if ((void*)&env->new_env != &env_array[3]) { stack[0].ival = 0; return 0; }
@@ -211,10 +211,10 @@ int32_t SPVM__TestCase__NativeAPI__check_native_api_indexes(SPVM_ENV* env, SPVM_
   if ((void*)&env->strerror_string_nolen != &env_array[193]) { stack[0].ival = 0; return 0; }
   if ((void*)&env->strerror != &env_array[194]) { stack[0].ival = 0; return 0; }
   if ((void*)&env->strerror_nolen != &env_array[195]) { stack[0].ival = 0; return 0; }
-  if ((void*)&env->allocator != &env_array[196]) { stack[0].ival = 0; return 0; }
-  if ((void*)&env->new_memory_env != &env_array[197]) { stack[0].ival = 0; return 0; }
-  if ((void*)&env->free_memory_env != &env_array[198]) { stack[0].ival = 0; return 0; }
-  if ((void*)&env->get_memory_blocks_count_env != &env_array[199]) { stack[0].ival = 0; return 0; }
+  if ((void*)&env->reserved196 != &env_array[196]) { stack[0].ival = 0; return 0; }
+  if ((void*)&env->reserved197 != &env_array[197]) { stack[0].ival = 0; return 0; }
+  if ((void*)&env->reserved198 != &env_array[198]) { stack[0].ival = 0; return 0; }
+  if ((void*)&env->reserved199 != &env_array[199]) { stack[0].ival = 0; return 0; }
   if ((void*)&env->new_memory_stack != &env_array[200]) { stack[0].ival = 0; return 0; }
   if ((void*)&env->free_memory_stack != &env_array[201]) { stack[0].ival = 0; return 0; }
   if ((void*)&env->get_memory_blocks_count_stack != &env_array[202]) { stack[0].ival = 0; return 0; }
@@ -1423,10 +1423,10 @@ int32_t SPVM__TestCase__NativeAPI__mortal_api(SPVM_ENV* env, SPVM_VALUE* stack)
 int32_t SPVM__TestCase__NativeAPI__enter_scope_leave_scope(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t length = 10;
-  int32_t start_memory_blocks_count = env->get_memory_blocks_count_env(env);
+  int32_t start_memory_blocks_count = env->get_memory_blocks_count(env, stack);
   env->new_int_array(env, stack, length);
   env->new_int_array(env, stack, length);
-  int32_t before_enter_memory_blocks_count = env->get_memory_blocks_count_env(env);
+  int32_t before_enter_memory_blocks_count = env->get_memory_blocks_count(env, stack);
   int32_t before_leave_memory_blocks_count;
   {
     int32_t scope_id = env->enter_scope(env, stack);
@@ -1435,11 +1435,11 @@ int32_t SPVM__TestCase__NativeAPI__enter_scope_leave_scope(SPVM_ENV* env, SPVM_V
     env->new_int_array(env, stack, length);
     env->new_int_array(env, stack, length);
     
-    before_leave_memory_blocks_count = env->get_memory_blocks_count_env(env);
+    before_leave_memory_blocks_count = env->get_memory_blocks_count(env, stack);
     env->leave_scope(env, stack, scope_id);
   }
   
-  int32_t after_leave_memory_blocks_counts = env->get_memory_blocks_count_env(env);
+  int32_t after_leave_memory_blocks_counts = env->get_memory_blocks_count(env, stack);
   
   stack[0].ival = 0;
   if ((before_enter_memory_blocks_count - start_memory_blocks_count) == 2) {
@@ -2277,18 +2277,18 @@ int32_t SPVM__TestCase__NativeAPI__new_memory_apis(SPVM_ENV* env, SPVM_VALUE* st
   int32_t error = 0;
   
   {
-    int32_t memory_blocks_count_env_start = env->get_memory_blocks_count_env(env);
+    int32_t memory_blocks_count_start = env->get_memory_blocks_count(env, stack);
     
-    void* memory_block = env->new_memory_env(env, sizeof(SPVM_ENV));
+    void* memory_block = env->new_memory_block(env, stack, sizeof(SPVM_ENV));
     
-    if (!(env->get_memory_blocks_count_env(env) == memory_blocks_count_env_start + 1)) {
+    if (!(env->get_memory_blocks_count(env, stack) == memory_blocks_count_start + 1)) {
       stack[0].ival = 0;
       return 0;
     }
     
-    env->free_memory_env(env, memory_block);
+    env->free_memory_block(env, stack, memory_block);
     
-    if (!(env->get_memory_blocks_count_env(env) == memory_blocks_count_env_start)) {
+    if (!(env->get_memory_blocks_count(env, stack) == memory_blocks_count_start)) {
       stack[0].ival = 0;
       return 0;
     }
@@ -2298,52 +2298,32 @@ int32_t SPVM__TestCase__NativeAPI__new_memory_apis(SPVM_ENV* env, SPVM_VALUE* st
     void* new_stack = env->new_stack(env);
     env->free_stack(env, new_stack);
   }
-
+  
   {
     void* new_stack = env->new_stack(env);
-
-    int32_t memory_blocks_count_env_start = env->get_memory_blocks_count_env(env);
     
-    int32_t memory_blocks_count_stack_start = env->get_memory_blocks_count_stack(env, stack);
-    int32_t memory_blocks_count_new_stack_start = env->get_memory_blocks_count_stack(env, new_stack);
+    int32_t memory_blocks_count_start_stack = env->get_memory_blocks_count(env, stack);
+    int32_t memory_blocks_count_start_new_stack = env->get_memory_blocks_count(env, new_stack);
     
-    void* memory_block_stack = env->new_memory_stack(env, stack, sizeof(SPVM_ENV));
-    void* memory_block_new_stack = env->new_memory_stack(env, new_stack, sizeof(SPVM_ENV));
-
-    if (!(env->get_memory_blocks_count_env(env) == memory_blocks_count_env_start + 2)) {
+    void* memory_block_new_stack = env->new_memory_block(env, new_stack, 8);
+    
+    if (!(env->get_memory_blocks_count(env, new_stack) == memory_blocks_count_start_new_stack + 1)) {
       stack[0].ival = 0;
       return 0;
     }
     
-    if (!(env->get_memory_blocks_count_stack(env, stack) == memory_blocks_count_stack_start + 1)) {
-      stack[0].ival = 0;
-      return 0;
-    }
-
-    if (!(env->get_memory_blocks_count_stack(env, new_stack) == memory_blocks_count_new_stack_start + 1)) {
+    if (!(env->get_memory_blocks_count(env, stack) == memory_blocks_count_start_stack)) {
       stack[0].ival = 0;
       return 0;
     }
     
+    env->free_memory_block(env, new_stack, memory_block_new_stack);
     
-    env->free_memory_stack(env, stack, memory_block_stack);
-    env->free_memory_stack(env, new_stack, memory_block_new_stack);
-
-    if (!(env->get_memory_blocks_count_env(env) == memory_blocks_count_env_start)) {
+    if (!(env->get_memory_blocks_count(env, new_stack) == memory_blocks_count_start_new_stack)) {
       stack[0].ival = 0;
       return 0;
     }
-    
-    if (!(env->get_memory_blocks_count_stack(env, stack) == memory_blocks_count_stack_start)) {
-      stack[0].ival = 0;
-      return 0;
-    }
-    
-    if (!(env->get_memory_blocks_count_stack(env, new_stack) == memory_blocks_count_new_stack_start)) {
-      stack[0].ival = 0;
-      return 0;
-    }
-    
+   
     env->free_stack(env, new_stack);
   }
   
@@ -2681,20 +2661,20 @@ int32_t SPVM__TestCase__NativeAPI__dumpc(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__TestCase__NativeAPI__check_stdin_stdout_stderr_binary_mode(SPVM_ENV* env, SPVM_VALUE* stack) {
 #ifdef _WIN32  
-  int32_t stdin_old_mode = _setmode(0, _O_BINARY);
+  int32_t stdin_old_mode = setmode(0, _O_BINARY);
   
   if (!(stdin_old_mode == _O_BINARY)) {
     stack[0].ival = 0;
     return 0;
   }
   
-  int32_t stdout_old_mode = _setmode(1, _O_BINARY);
+  int32_t stdout_old_mode = setmode(1, _O_BINARY);
   if (!(stdout_old_mode == _O_BINARY)) {
     stack[0].ival = 0;
     return 0;
   }
   
-  int32_t stderr_old_mode = _setmode(2, _O_BINARY);
+  int32_t stderr_old_mode = setmode(2, _O_BINARY);
   if (!(stderr_old_mode == _O_BINARY)) {
     stack[0].ival = 0;
     return 0;
@@ -2902,6 +2882,60 @@ int32_t SPVM__TestCase__NativeAPI__get_object_basic_type_name(SPVM_ENV* env, SPV
   return 0;
 }
 
+int32_t SPVM__TestCase__NativeAPI__save_stdout_windows_binary_mode(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t error = 0;
+  
+#ifdef _WIN32
+  int32_t stdout_mode_current = setmode(fileno(stdout), _O_BINARY);
+  if (!(stdout_mode_current == _O_BINARY)) {
+    return env->die(env, stack, "stdout mode must be _O_BINARY.");
+  }
+  
+  env->set_class_var_int_by_name(env, stack, "TestCase::NativeAPI", "$STDOUT_WINDOWS_BINARY_MODE", stdout_mode_current, &error, __func__, FILE_NAME, __LINE__);
+  if (error) { return error; }
+  
+#endif
+  
+  return 0;
+}
+
+int32_t SPVM__TestCase__NativeAPI__save_stderr_windows_binary_mode(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t error = 0;
+  
+#ifdef _WIN32
+  int32_t stderr_mode_current = setmode(fileno(stderr), _O_BINARY);
+  if (!(stderr_mode_current == _O_BINARY)) {
+    return env->die(env, stack, "stderr mode must be _O_BINARY.");
+  }
+  
+  env->set_class_var_int_by_name(env, stack, "TestCase::NativeAPI", "$STDERR_WINDOWS_BINARY_MODE", stderr_mode_current, &error, __func__, FILE_NAME, __LINE__);
+  if (error) { return error; }
+  
+#endif
+  
+  return 0;
+}
+
+int32_t SPVM__TestCase__NativeAPI__save_stdin_windows_binary_mode(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t error = 0;
+  
+#ifdef _WIN32
+  int32_t stdin_mode_current = setmode(fileno(stdin), _O_BINARY);
+  if (!(stdin_mode_current == _O_BINARY)) {
+    return env->die(env, stack, "stdin mode must be _O_BINARY.");
+  }
+  
+  env->set_class_var_int_by_name(env, stack, "TestCase::NativeAPI", "$STDIN_WINDOWS_BINARY_MODE", stdin_mode_current, &error, __func__, FILE_NAME, __LINE__);
+  if (error) { return error; }
+  
+#endif
+  
+  return 0;
+}
+
 int32_t SPVM__TestCase__NativeAPI__freopen_stdout(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t error = 0;
@@ -2914,12 +2948,31 @@ int32_t SPVM__TestCase__NativeAPI__freopen_stdout(SPVM_ENV* env, SPVM_VALUE* sta
   
   const char* path = env->get_chars(env, stack, obj_path);
   
-  FILE* fp = freopen(path, "wb", stdout);
+  FILE* fp = freopen(path, "w", stdout);
   
   if (!fp) {
     return env->die(env, stack, "freopen failed.");
   }
   
+#ifdef _WIN32
+  int32_t stdout_mode_current = env->get_class_var_int_by_name(env, stack, "TestCase::NativeAPI", "$STDOUT_WINDOWS_BINARY_MODE", &error, __func__, FILE_NAME, __LINE__);
+  if (error) { return error; }
+  setmode(fileno(fp), stdout_mode_current);
+#endif
+  
+  return 0;
+}
+
+int32_t SPVM__TestCase__NativeAPI__close_stdout(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t error = 0;
+  
+  int32_t status = fclose(stdout);
+  
+  if (!(status == 0)) {
+    return env->die(env, stack, "fclose failed.");
+  }
+  
   return 0;
 }
 
@@ -2935,11 +2988,30 @@ int32_t SPVM__TestCase__NativeAPI__freopen_stderr(SPVM_ENV* env, SPVM_VALUE* sta
   
   const char* path = env->get_chars(env, stack, obj_path);
   
-  FILE* fp = freopen(path, "wb", stderr);
+  FILE* fp = freopen(path, "w", stderr);
   
   if (!fp) {
     return env->die(env, stack, "freopen failed.");
   }
   
+#ifdef _WIN32
+  int32_t stderr_mode_current = env->get_class_var_int_by_name(env, stack, "TestCase::NativeAPI", "$STDERR_WINDOWS_BINARY_MODE", &error, __func__, FILE_NAME, __LINE__);
+  setmode(fileno(fp), stderr_mode_current);
+#endif
+  
   return 0;
 }
+
+int32_t SPVM__TestCase__NativeAPI__close_stderr(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t error = 0;
+  
+  int32_t status = fclose(stderr);
+  
+  if (!(status == 0)) {
+    return env->die(env, stack, "fclose failed.");
+  }
+  
+  return 0;
+}
+
